==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1StatefulSetUpdateStrategyFluent.java <==
package io.kubernetes.client.models;

import java.lang.Deprecated;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Boolean;

public interface V1StatefulSetUpdateStrategyFluent<A extends V1StatefulSetUpdateStrategyFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildRollingUpdate instead.
 * @return The buildable object.
 */
@Deprecated public V1RollingUpdateStatefulSetStrategy getRollingUpdate();
    public V1RollingUpdateStatefulSetStrategy buildRollingUpdate();
    public A withRollingUpdate(V1RollingUpdateStatefulSetStrategy rollingUpdate);
    public Boolean hasRollingUpdate();
    public V1StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate();
    public V1StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(V1RollingUpdateStatefulSetStrategy item);
    public V1StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editRollingUpdate();
    public V1StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate();
    public V1StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(V1RollingUpdateStatefulSetStrategy item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();

    public interface RollingUpdateNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1RollingUpdateStatefulSetStrategyFluent<V1StatefulSetUpdateStrategyFluent.RollingUpdateNested<N>>{

        
    public N and();    public N endRollingUpdate();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1StatefulSetUpdateStrategyFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1StatefulSetUpdateStrategyFluent<A extends V1StatefulSetUpdateStrategyFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildRollingUpdate instead.
 * @return The buildable object.
 */
@Deprecated public V1RollingUpdateStatefulSetStrategy getRollingUpdate();
    public V1RollingUpdateStatefulSetStrategy buildRollingUpdate();
    public A withRollingUpdate(V1RollingUpdateStatefulSetStrategy rollingUpdate);
    public Boolean hasRollingUpdate();
    public V1StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate();
    public V1StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(V1RollingUpdateStatefulSetStrategy item);
    public V1StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editRollingUpdate();
    public V1StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate();
    public V1StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(V1RollingUpdateStatefulSetStrategy item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);

    public interface RollingUpdateNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1RollingUpdateStatefulSetStrategyFluent<V1StatefulSetUpdateStrategyFluent.RollingUpdateNested<N>>{

        
    public N and();    public N endRollingUpdate();
}


}
